==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp3445_001/MP3445_GetNonconformityObservation_001.java <==

package net.datastream.schemas.mp_functions.mp3445_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NONCONFORMITYOBSERVATIONID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYOBSERVATIONID"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="NonconformityObservation" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="is_from_wononconformity" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "nonconformityobservationid"
})
@XmlRootElement(name = "MP3445_GetNonconformityObservation_001")
public class MP3445_GetNonconformityObservation_001 {

    @XmlElement(name = "NONCONFORMITYOBSERVATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected NONCONFORMITYOBSERVATIONID_Type nonconformityobservationid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "is_from_wononconformity")
    protected String is_From_Wononconformity;

    /**
     * Gets the value of the nonconformityobservationid property.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYOBSERVATIONID_Type }
     *     
     */
    public NONCONFORMITYOBSERVATIONID_Type getNONCONFORMITYOBSERVATIONID() {
        return nonconformityobservationid;
    }

    /**
     * Sets the value of the nonconformityobservationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYOBSERVATIONID_Type }
     *     
     */
    public void setNONCONFORMITYOBSERVATIONID(NONCONFORMITYOBSERVATIONID_Type value) {
        this.nonconformityobservationid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.NONCONFORMITY_OBSERVATION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the is_From_Wononconformity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_From_Wononconformity() {
        if (is_From_Wononconformity == null) {
            return "false";
        } else {
            return is_From_Wononconformity;
        }
    }

    /**
     * Sets the value of the is_From_Wononconformity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_From_Wononconformity(String value) {
        this.is_From_Wononconformity = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_functions/mp3445_001/MP3445_GetNonconformityObservation_001.java <==

package net.datastream.schemas.mp_functions.mp3445_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NONCONFORMITYOBSERVATIONID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYOBSERVATIONID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="NonconformityObservation" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="is_from_wononconformity" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "nonconformityobservationid"
})
@XmlRootElement(name = "MP3445_GetNonconformityObservation_001")
public class MP3445_GetNonconformityObservation_001 {

    @XmlElement(name = "NONCONFORMITYOBSERVATIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected NONCONFORMITYOBSERVATIONID_Type nonconformityobservationid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "is_from_wononconformity")
    protected String is_From_Wononconformity;

    /**
     * Gets the value of the nonconformityobservationid property.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYOBSERVATIONID_Type }
     *     
     */
    public NONCONFORMITYOBSERVATIONID_Type getNONCONFORMITYOBSERVATIONID() {
        return nonconformityobservationid;
    }

    /**
     * Sets the value of the nonconformityobservationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYOBSERVATIONID_Type }
     *     
     */
    public void setNONCONFORMITYOBSERVATIONID(NONCONFORMITYOBSERVATIONID_Type value) {
        this.nonconformityobservationid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.NONCONFORMITY_OBSERVATION;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the is_From_Wononconformity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_From_Wononconformity() {
        if (is_From_Wononconformity == null) {
            return "false";
        } else {
            return is_From_Wononconformity;
        }
    }

    /**
     * Sets the value of the is_From_Wononconformity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_From_Wononconformity(String value) {
        this.is_From_Wononconformity = value;
    }

}
